package cz...;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.HibernateException;
import org.hibernate.Session;
import org.hibernate.SessionFactory;
import org.hibernate.cfg.Configuration;

public class HibernateUtil  {

  private static Log log = LogFactory.getLog(HibernateUtil.class);
  private static final SessionFactory sessionFactory;
  
  static {
    try {
      sessionFactory = new Configuration().configure().buildSessionFactory();
    }
    catch (Throwable ex){
      log.error("Initial Session Factory creation failed", ex);
      throw new ExceptionInInitializerError(ex);
    }
  } 

  public static final ThreadLocal session = new ThreadLocal();
  
  public static synchronized Session currentSession() throws HibernateException {
    Session s = (Session)session.get();
    if (s == null) {
      s = sessionFactory.openSession();
      session.set(s);
    }
    return s;
  }
  
  public static void closeSession() throws HibernateException {
    Session s = (Session)session.get();
    if (s != null) {
      synchronized(s) {
        session.set(null);
        s.close();
      }
    }
  }
  
  public static synchronized java.io.Serializable getId(Object item) throws HibernateException {
    return currentSession().getIdentifier(item);
  }
  
  public static SessionFactory getSessionFactory() {
    return sessionFactory;
  }

}
